package edu.nyu.scps.client;

import android.os.AsyncTask;
import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.TextView;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;


public class MainActivity extends ActionBarActivity {
    int n = 3;  //number of records in table, numbered from 1 to n inclusive
    String[] lastnames = new String[n+1];

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        GetTask getTask = new GetTask();
        getTask.execute(1);
    }

    private class GetTask extends AsyncTask<Integer, Void, Integer> {
        @Override
        protected Integer doInBackground(Integer... t) {
            //Must be declared outside of try block,
            //so we can mention them in finally block.
            HttpURLConnection httpURLConnection = null;
            BufferedReader bufferedReader = null;

            try {
                for (int i = 1; i <= n; ++i) {
                    URL url = new URL("http://i5.nyu.edu:3000/?_id=" + i);
                    httpURLConnection = (HttpURLConnection) url.openConnection();
                    httpURLConnection.setRequestMethod("GET");
                    httpURLConnection.connect();

                    InputStream inputStream = httpURLConnection.getInputStream();
                    if (inputStream == null) {
                        return null;
                    }

                    StringBuffer buffer = new StringBuffer();
                    InputStreamReader inputStreamReader = new InputStreamReader(inputStream);
                    bufferedReader = new BufferedReader(inputStreamReader);

                    String line;
                    while ((line = bufferedReader.readLine()) != null) {
                        buffer.append(line);
                    }

                    if (buffer.length() == 0) {
                        return null;
                    }
                    lastnames[i] = buffer.toString();
                }
            } catch (IOException exception) {
                Log.e("myTag", "GetTask doInBackground", exception);
                return null;
            } finally {
                if (httpURLConnection != null) {
                    httpURLConnection.disconnect();
                }
                if (bufferedReader != null) {
                    try {
                        bufferedReader.close();
                    } catch (final IOException exception) {
                        Log.e("myTag", "GetTask doInBackground", exception);
                    }
                }
            }
            return t[0];
        }

        @Override
        protected void onPostExecute(Integer t) {
            doneWithGet(t);
        }
    }

    private void doneWithGet(Integer t) {
        TextView textView = (TextView) findViewById(R.id.textView);
        for (int i = 1; i <= n; ++i) {
            textView.append(i + " " + lastnames[i] + "\n");
        }

        //If this was the first time we executed the GetTask, do a PutTask.
        if (t.intValue() == 1) {
            textView.append("\n");
            PutTask putTask = new PutTask();
            putTask.execute("Jeff");
        }
    }

    private class PutTask extends AsyncTask<String, Void, Void> {
        @Override
        protected Void doInBackground(String... name) {
            //Must be declared outside of try block,
            //so we can mention it in finally block.
            HttpURLConnection httpURLConnection = null;

            try {
                URL url = new URL("http://i5.nyu.edu:3000/?_id=3&lastname=" + name[0]);
                httpURLConnection = (HttpURLConnection)url.openConnection();
                httpURLConnection.setRequestMethod("PUT");
                httpURLConnection.setDoInput(true);
                httpURLConnection.setDoOutput(true);
                OutputStream outputStream = httpURLConnection.getOutputStream();
                InputStream inputStream = httpURLConnection.getInputStream();
            } catch (IOException exception) {
                Log.e("myTag", "PutTask doInBackground", exception);
            } finally {
                if (httpURLConnection != null) {
                    httpURLConnection.disconnect();
                }
            }
            return null;
        }

        @Override
        protected void onPostExecute(Void v) {
            doneWithPut();
        }
    }

    private void doneWithPut() {
        GetTask getTask = new GetTask();
        getTask.execute(2);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

}
